@@ -108,9 +108,9 @@ impl From<FileTransferParams> for Bookmark {
                 smb: Some(SmbParams::from(params.clone())),
                 protocol,
                 address: Some(params.address),
-                #[cfg(unix)]
+                #[cfg(posix)]
                 port: Some(params.port),
-                #[cfg(windows)]
+                #[cfg(win)]
                 port: None,
                 username: params.username,
                 password: params.password,
@@ -159,7 +159,7 @@ impl From<Bookmark> for FileTransferParams {
                 let params = KubeProtocolParams::from(params);
                 Self::new(bookmark.protocol, ProtocolParams::Kube(params))
             }
-            #[cfg(unix)]
+            #[cfg(posix)]
             FileTransferProtocol::Smb => {
                 let params = TransferSmbParams::new(
                     bookmark.address.unwrap_or_default(),
@@ -172,7 +172,7 @@ impl From<Bookmark> for FileTransferParams {
 
                 Self::new(bookmark.protocol, ProtocolParams::Smb(params))
             }
-            #[cfg(windows)]
+            #[cfg(win)]
             FileTransferProtocol::Smb => {
                 let params = TransferSmbParams::new(
                     bookmark.address.unwrap_or_default(),
@@ -521,7 +521,7 @@ mod tests {
     }
 
     #[test]
-    #[cfg(unix)]
+    #[cfg(posix)]
     fn should_get_ftparams_from_smb_bookmark() {
         let bookmark: Bookmark = Bookmark {
             protocol: FileTransferProtocol::Smb,
@@ -559,7 +559,7 @@ mod tests {
     }
 
     #[test]
-    #[cfg(windows)]
+    #[cfg(win)]
     fn should_get_ftparams_from_smb_bookmark() {
         let bookmark: Bookmark = Bookmark {
             protocol: FileTransferProtocol::Smb,
