@@ -2,11 +2,14 @@
 //!
 //! this module exposes some extra run modes for termscp, meant to be used for "support", such as installing themes
 
-// mod
+mod import_ssh_hosts;
+
 use std::fs;
 use std::path::{Path, PathBuf};
 
+pub use self::import_ssh_hosts::import_ssh_hosts;
 use crate::system::auto_update::{Update, UpdateStatus};
+use crate::system::bookmarks_client::BookmarksClient;
 use crate::system::config_client::ConfigClient;
 use crate::system::environment;
 use crate::system::notifications::Notification;
@@ -83,3 +86,36 @@ fn get_config_client() -> Option<ConfigClient> {
         }
     }
 }
+
+/// Init [`BookmarksClient`].
+pub fn bookmarks_client(keyring: bool) -> Result<Option<BookmarksClient>, String> {
+    // Get config dir
+    match environment::init_config_dir() {
+        Ok(path) => {
+            // If some configure client, otherwise do nothing; don't bother users telling them that bookmarks are not supported on their system.
+            if let Some(config_dir_path) = path {
+                let bookmarks_file: PathBuf =
+                    environment::get_bookmarks_paths(config_dir_path.as_path());
+                // Initialize client
+                BookmarksClient::new(
+                    bookmarks_file.as_path(),
+                    config_dir_path.as_path(),
+                    16,
+                    keyring,
+                )
+                .map(Option::Some)
+                .map_err(|e| {
+                    format!(
+                        "Could not initialize bookmarks (at \"{}\", \"{}\"): {}",
+                        bookmarks_file.display(),
+                        config_dir_path.display(),
+                        e
+                    )
+                })
+            } else {
+                Ok(None)
+            }
+        }
+        Err(err) => Err(err),
+    }
+}
