@@ -5,12 +5,12 @@
 // locals
 use std::path::PathBuf;
 
-use super::{FileTransferActivity, LogLevel, SelectedFile};
+use super::{FileTransferActivity, LogLevel};
 
 impl FileTransferActivity {
     /// Create symlink on localhost
     pub(crate) fn action_local_symlink(&mut self, name: String) {
-        if let SelectedFile::One(entry) = self.get_local_selected_entries() {
+        if let Some(entry) = self.get_local_selected_file() {
             match self
                 .host_bridge
                 .symlink(PathBuf::from(name.as_str()).as_path(), entry.path())
@@ -34,7 +34,7 @@ impl FileTransferActivity {
 
     /// Copy file on remote
     pub(crate) fn action_remote_symlink(&mut self, name: String) {
-        if let SelectedFile::One(entry) = self.get_remote_selected_entries() {
+        if let Some(entry) = self.get_remote_selected_file() {
             match self
                 .client
                 .symlink(PathBuf::from(name.as_str()).as_path(), entry.path())
