@@ -5,7 +5,6 @@
 // locals
 // externals
 use remotefs::fs::File;
-use tuirealm::props::{AttrValue, Attribute};
 use tuirealm::{State, StateValue, Update};
 
 use super::actions::SelectedFile;
@@ -153,6 +152,9 @@ impl FileTransferActivity {
                     _ => panic!("Found tab doesn't support EXEC"),
                 };
             }
+            TransferMsg::GetFileSize => {
+                self.action_get_file_size();
+            }
             TransferMsg::GoTo(dir) => {
                 match self.browser.tab() {
                     FileExplorerTab::HostBridge => self.action_change_local_dir(dir),
@@ -504,15 +506,6 @@ impl FileTransferActivity {
                 self.disconnect_and_quit();
                 self.umount_quit();
             }
-            UiMsg::ReplacePopupTabbed => {
-                if let Ok(Some(AttrValue::Flag(true))) =
-                    self.app.query(&Id::ReplacePopup, Attribute::Focus)
-                {
-                    assert!(self.app.active(&Id::ReplacingFilesListPopup).is_ok());
-                } else {
-                    assert!(self.app.active(&Id::ReplacePopup).is_ok());
-                }
-            }
             UiMsg::ShowChmodPopup => {
                 let selected_file = match self.browser.tab() {
                     #[cfg(posix)]
