@@ -11,8 +11,8 @@ use tuirealm::ratatui::layout::{Constraint, Direction, Layout};
 use tuirealm::{State, StateValue};
 
 use super::{
-    components, Context, Id, IdCommon, IdConfig, SetupActivity, ViewLayout, RADIO_PROTOCOL_KUBE,
-    RADIO_PROTOCOL_WEBDAV,
+    Context, Id, IdCommon, IdConfig, RADIO_PROTOCOL_KUBE, RADIO_PROTOCOL_WEBDAV, SetupActivity,
+    ViewLayout, components,
 };
 use crate::explorer::GroupDirs;
 use crate::filetransfer::FileTransferProtocol;
@@ -145,122 +145,133 @@ impl SetupActivity {
         // Text editor
         let text_editor: String =
             String::from(self.config().get_text_editor().as_path().to_string_lossy());
-        assert!(self
-            .app
-            .remount(
-                Id::Config(IdConfig::TextEditor),
-                Box::new(components::TextEditor::new(text_editor.as_str())),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::Config(IdConfig::TextEditor),
+                    Box::new(components::TextEditor::new(text_editor.as_str())),
+                    vec![]
+                )
+                .is_ok()
+        );
         // Protocol
-        assert!(self
-            .app
-            .remount(
-                Id::Config(IdConfig::DefaultProtocol),
-                Box::new(components::DefaultProtocol::new(
-                    self.config().get_default_protocol()
-                )),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::Config(IdConfig::DefaultProtocol),
+                    Box::new(components::DefaultProtocol::new(
+                        self.config().get_default_protocol()
+                    )),
+                    vec![]
+                )
+                .is_ok()
+        );
         // Hidden files
-        assert!(self
-            .app
-            .remount(
-                Id::Config(IdConfig::HiddenFiles),
-                Box::new(components::HiddenFiles::new(
-                    self.config().get_show_hidden_files()
-                )),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::Config(IdConfig::HiddenFiles),
+                    Box::new(components::HiddenFiles::new(
+                        self.config().get_show_hidden_files()
+                    )),
+                    vec![]
+                )
+                .is_ok()
+        );
         // Updates
-        assert!(self
-            .app
-            .remount(
-                Id::Config(IdConfig::CheckUpdates),
-                Box::new(components::CheckUpdates::new(
-                    self.config().get_check_for_updates()
-                )),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::Config(IdConfig::CheckUpdates),
+                    Box::new(components::CheckUpdates::new(
+                        self.config().get_check_for_updates()
+                    )),
+                    vec![]
+                )
+                .is_ok()
+        );
         // File replace
-        assert!(self
-            .app
-            .remount(
-                Id::Config(IdConfig::PromptOnFileReplace),
-                Box::new(components::PromptOnFileReplace::new(
-                    self.config().get_prompt_on_file_replace()
-                )),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::Config(IdConfig::PromptOnFileReplace),
+                    Box::new(components::PromptOnFileReplace::new(
+                        self.config().get_prompt_on_file_replace()
+                    )),
+                    vec![]
+                )
+                .is_ok()
+        );
         // Group dirs
-        assert!(self
-            .app
-            .remount(
-                Id::Config(IdConfig::GroupDirs),
-                Box::new(components::GroupDirs::new(self.config().get_group_dirs())),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::Config(IdConfig::GroupDirs),
+                    Box::new(components::GroupDirs::new(self.config().get_group_dirs())),
+                    vec![]
+                )
+                .is_ok()
+        );
         // Local File Fmt
-        assert!(self
-            .app
-            .remount(
-                Id::Config(IdConfig::LocalFileFmt),
-                Box::new(components::LocalFileFmt::new(
-                    &self.config().get_local_file_fmt().unwrap_or_default()
-                )),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::Config(IdConfig::LocalFileFmt),
+                    Box::new(components::LocalFileFmt::new(
+                        &self.config().get_local_file_fmt().unwrap_or_default()
+                    )),
+                    vec![]
+                )
+                .is_ok()
+        );
         // Remote File Fmt
-        assert!(self
-            .app
-            .remount(
-                Id::Config(IdConfig::RemoteFileFmt),
-                Box::new(components::RemoteFileFmt::new(
-                    &self.config().get_remote_file_fmt().unwrap_or_default()
-                )),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::Config(IdConfig::RemoteFileFmt),
+                    Box::new(components::RemoteFileFmt::new(
+                        &self.config().get_remote_file_fmt().unwrap_or_default()
+                    )),
+                    vec![]
+                )
+                .is_ok()
+        );
         // Notifications enabled
-        assert!(self
-            .app
-            .remount(
-                Id::Config(IdConfig::NotificationsEnabled),
-                Box::new(components::NotificationsEnabled::new(
-                    self.config().get_notifications()
-                )),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::Config(IdConfig::NotificationsEnabled),
+                    Box::new(components::NotificationsEnabled::new(
+                        self.config().get_notifications()
+                    )),
+                    vec![]
+                )
+                .is_ok()
+        );
         // Notifications threshold
-        assert!(self
-            .app
-            .remount(
-                Id::Config(IdConfig::NotificationsThreshold),
-                Box::new(components::NotificationsThreshold::new(&fmt_bytes(
-                    self.config().get_notification_threshold()
-                ))),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::Config(IdConfig::NotificationsThreshold),
+                    Box::new(components::NotificationsThreshold::new(&fmt_bytes(
+                        self.config().get_notification_threshold()
+                    ))),
+                    vec![]
+                )
+                .is_ok()
+        );
         // Ssh config
-        assert!(self
-            .app
-            .remount(
-                Id::Config(IdConfig::SshConfig),
-                Box::new(components::SshConfig::new(
-                    self.config().get_ssh_config().unwrap_or("")
-                )),
-                vec![]
-            )
-            .is_ok());
+        assert!(
+            self.app
+                .remount(
+                    Id::Config(IdConfig::SshConfig),
+                    Box::new(components::SshConfig::new(
+                        self.config().get_ssh_config().unwrap_or("")
+                    )),
+                    vec![]
+                )
+                .is_ok()
+        );
     }
 
     /// Collect values from input and put them into the configuration
